@@ -24,9 +24,10 @@ QStringList schema()
 {
     // If only we could use initializer lists here ...
 
+    /* clang-format off */
     return QStringList()
 
-        << // Schema informations table, used for versioning
+        << // Schema information table, used for versioning
            QStringLiteral("CREATE TABLE IF NOT EXISTS SchemaInfo ("
                "key text PRIMARY KEY, value text"
            ")")
@@ -47,7 +48,7 @@ QStringList schema()
                "end INTEGER "
            ")")
 
-        << // The ResourceScoreCache table stores the calcualted scores
+        << // The ResourceScoreCache table stores the calculated scores
            // for resources based on the recorded events.
            QStringLiteral("CREATE TABLE IF NOT EXISTS ResourceScoreCache ("
                "usedActivity TEXT, "
@@ -91,6 +92,7 @@ QStringList schema()
            ")")
 
        ;
+    /* clang-format on */
 }
 
 // TODO: This will require some refactoring after we introduce more databases
@@ -108,10 +110,12 @@ QString path()
 {
     auto app = QCoreApplication::instance();
 
+    /* clang-format off */
     return
         (app->property(overrideFlagProperty).toBool()) ?
             app->property(overrideFileProperty).toString() :
             defaultPath();
+    /* clang-format on */
 }
 
 void overridePath(const QString &path)
@@ -126,7 +130,7 @@ void initSchema(Database &database)
 {
     QString dbSchemaVersion;
 
-    auto query = database.execQuery(
+    auto query = database.execQuery( //
         QStringLiteral("SELECT value FROM SchemaInfo WHERE key = 'version'"));
 
     if (query.next()) {
@@ -145,9 +149,9 @@ void initSchema(Database &database)
     // so that we do not create new (empty) tables and block these
     // queries from being executed.
     if (dbSchemaVersion < QStringLiteral("2014.04.14")) {
-        database.execQuery(
+        database.execQuery( //
             QStringLiteral("ALTER TABLE nuao_DesktopEvent RENAME TO ResourceEvent"));
-        database.execQuery(
+        database.execQuery( //
             QStringLiteral("ALTER TABLE kext_ResourceScoreCache RENAME TO ResourceScoreCache"));
     }
 
@@ -157,6 +161,7 @@ void initSchema(Database &database)
     // be at least magic values. These do not change the structure
     // of the database, but the old data.
     if (dbSchemaVersion < QStringLiteral("2015.02.09")) {
+        /* clang-format off */
         const QString updateActivity =
             QStringLiteral("SET usedActivity=':global' "
             "WHERE usedActivity IS NULL OR usedActivity = ''");
@@ -180,6 +185,7 @@ void initSchema(Database &database)
         database.execQuery(QStringLiteral("UPDATE ResourceScoreCache ") + updateActivity);
         database.execQuery(QStringLiteral("UPDATE ResourceScoreCache ") + updateAgent);
 
+        /* clang-format on */
     }
 }
 
