@@ -1,23 +1,8 @@
 /*
- *   Copyright (C) 2015, 2016 Ivan Cukic <ivan.cukic(at)kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) version 3, or any
- *   later version accepted by the membership of KDE e.V. (or its
- *   successor approved by the membership of KDE e.V.), which shall
- *   act as a proxy defined in Section 6 of version 3 of the license.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.
- *   If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2015, 2016 Ivan Cukic <ivan.cukic(at)kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include "resultset.h"
 
@@ -35,8 +20,7 @@
 #include <utils/qsqlquery_iterator.h>
 #include "kactivities-stats-logsettings.h"
 
-// Boost and STL
-#include <boost/range/algorithm/transform.hpp>
+// STL
 #include <iterator>
 #include <functional>
 #include <mutex>
@@ -92,6 +76,7 @@ ResultSet::Result::~Result()
     delete d;
 }
 
+/* clang-format off */
 #define CREATE_GETTER_AND_SETTER(Type, Name, Set)                              \
     Type ResultSet::Result::Name() const                                       \
     {                                                                          \
@@ -102,6 +87,7 @@ ResultSet::Result::~Result()
     {                                                                          \
         d->Name = Name;                                                        \
     }
+/* clang-format on */
 
 CREATE_GETTER_AND_SETTER(QString, resource, setResource)
 CREATE_GETTER_AND_SETTER(QString, title, setTitle)
@@ -139,11 +125,13 @@ public:
 
         auto selection = queryDefinition.selection();
 
+        /* clang-format off */
         query = database->execQuery(replaceQueryParameters(
                 selection == LinkedResources ? linkedResourcesQuery()
               : selection == UsedResources   ? usedResourcesQuery()
               : selection == AllResources    ? allResourcesQuery()
               : QString()));
+        /* clang-format on */
 
         if (query.lastError().isValid()) {
             qCWarning(KACTIVITIES_STATS_LOG) << "[Error at ResultSetPrivate::initQuery]: " << query.lastError();
@@ -152,22 +140,30 @@ public:
 
     QString agentClause(const QString &agent) const
     {
-        if (agent == QLatin1String(":any")) return QStringLiteral("1");
+        if (agent == QLatin1String(":any")) {
+            return QStringLiteral("1");
+        }
 
+        /* clang-format off */
         return QStringLiteral("agent = '") + (
                 agent == QLatin1String(":current") ? QCoreApplication::instance()->applicationName() :
                                       agent
             ) + QStringLiteral("'");
+        /* clang-format on */
     }
 
     QString activityClause(const QString &activity) const
     {
-        if (activity == QLatin1String(":any")) return QStringLiteral("1");
+        if (activity == QLatin1String(":any")) {
+            return QStringLiteral("1");
+        }
 
+        /* clang-format off */
         return QStringLiteral("activity = '") + (
                 activity == QLatin1String(":current") ? ActivitiesSync::currentActivity(activities) :
                                          activity
             ) + QStringLiteral("'");
+        /* clang-format on */
     }
 
     inline QString starPattern(const QString &pattern) const
@@ -179,17 +175,23 @@ public:
 
     QString urlFilterClause(const QString &urlFilter) const
     {
-        if (urlFilter == QLatin1String("*")) return QStringLiteral("1");
+        if (urlFilter == QLatin1String("*")) {
+            return QStringLiteral("1");
+        }
 
         return QStringLiteral("resource LIKE '") + Common::starPatternToLike(urlFilter) + QStringLiteral("' ESCAPE '\\'");
     }
 
     QString mimetypeClause(const QString &mimetype) const
     {
-        if (mimetype == ANY_TYPE_TAG || mimetype == QLatin1String("*")) return QStringLiteral("1");
+        if (mimetype == ANY_TYPE_TAG || mimetype == QLatin1String("*")) {
+            return QStringLiteral("1");
 
-        else if (mimetype == FILES_TYPE_TAG) return QStringLiteral("mimetype != 'inode/directory' AND mimetype != ''");
-        else if (mimetype == DIRECTORIES_TYPE_TAG) return QStringLiteral("mimetype = 'inode/directory'");
+        } else if (mimetype == FILES_TYPE_TAG) {
+            return QStringLiteral("mimetype != 'inode/directory' AND mimetype != ''");
+        } else if (mimetype == DIRECTORIES_TYPE_TAG) {
+            return QStringLiteral("mimetype = 'inode/directory'");
+        }
 
         return QStringLiteral("mimetype LIKE '") + Common::starPatternToLike(mimetype) + QStringLiteral("' ESCAPE '\\'");
     }
@@ -228,7 +230,7 @@ public:
         using namespace std::placeholders;
 
         QStringList result;
-        boost::transform(input,
+        std::transform(input.cbegin(), input.cend(),
                          std::back_inserter(result),
                          std::bind(f, this, _1));
 
@@ -256,6 +258,7 @@ public:
     {
         // ORDER BY column
         auto ordering = queryDefinition.ordering();
+        /* clang-format off */
         QString orderingColumn = QStringLiteral("linkStatus DESC, ") + (
                 ordering == HighScoredFirst      ? QStringLiteral("score DESC,")
               : ordering == RecentlyCreatedFirst ? QStringLiteral("firstUpdate DESC,")
@@ -263,6 +266,7 @@ public:
               : ordering == OrderByTitle         ? QStringLiteral("title ASC,")
               : QString()
             );
+        /* clang-format on */
 
         // WHERE clause for filtering on agents
         QStringList agentsFilter = transformedList(
@@ -280,7 +284,8 @@ public:
         QStringList mimetypeFilter = transformedList(
                 queryDefinition.types(), &ResultSetPrivate::mimetypeClause);
 
-        QString dateColumn = QStringLiteral("1"), resourceEventJoin;
+        QString dateColumn = QStringLiteral("1");
+        QString resourceEventJoin;
         // WHERE clause for access date filtering and ResourceEvent table Join
         if (!queryDefinition.dateStart().isNull()) {
             dateColumn = dateClause(queryDefinition.dateStart(), queryDefinition.dateEnd());
@@ -310,6 +315,7 @@ public:
         // TODO: We need to correct the scores based on the time that passed
         //       since the cache was last updated, although, for this query,
         //       scores are not that important.
+        /* clang-format off */
         static const QString queryString =
             QStringLiteral(R"sql(
             SELECT
@@ -349,6 +355,7 @@ public:
             LIMIT_CLAUSE
             )sql")
             ;
+        /* clang-format on */
 
         return queryString;
     }
@@ -495,7 +502,9 @@ public:
     {
         ResultSet::Result result;
 
-        if (!database || !query.isActive()) return result;
+        if (!database || !query.isActive()) {
+            return result;
+        }
 
         result.setResource(query.value(QStringLiteral("resource")).toString());
         result.setTitle(query.value(QStringLiteral("title")).toString());
@@ -573,7 +582,9 @@ ResultSet::~ResultSet()
 
 ResultSet::Result ResultSet::at(int index) const
 {
-    if (!d->query.isActive()) return Result();
+    if (!d->query.isActive()) {
+        return Result();
+    }
 
     d->query.seek(index);
 
