@@ -23,8 +23,6 @@
 
 #include <KActivities/Consumer>
 
-#include <boost/range/numeric.hpp>
-
 namespace KAStats = KActivities::Stats;
 
 using namespace KAStats;
@@ -211,8 +209,8 @@ Window::Window()
     /* clang-format on */
 
     ui->comboPreset->addItem(QStringLiteral("Choose a preset"), QVariant());
-    for (const auto& presetId: presets.keys()) {
-        ui->comboPreset->addItem(presetId, presetId);
+    for (auto it = presets.cbegin(); it != presets.cend(); ++it) {
+        ui->comboPreset->addItem(it.key(), it.key());
     }
 
     connect(ui->comboPreset, SIGNAL(activated(int)),
@@ -227,7 +225,9 @@ void Window::selectPreset()
 {
     const auto id = ui->comboPreset->currentData().toString();
 
-    if (id.isEmpty()) return;
+    if (id.isEmpty()) {
+        return;
+    }
 
     const auto &query = presets[id];
     qDebug() << "Id: " << id;
@@ -342,11 +342,7 @@ void Window::updateResults()
         Activity(ui->comboActivity->currentText().split(QLatin1Char(','))) |
 
         // And URL filters
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        Url(ui->textUrl->text().split(QLatin1Char(','), QString::SkipEmptyParts)) |
-#else
         Url(ui->textUrl->text().split(QLatin1Char(','), Qt::SkipEmptyParts)) |
-#endif
 
         // And date filter
         (
